SHR_dataset_name      <- system.file("extdata",
                                     "example_data.zip",
                                     package = "asciiSetupReader")
SHR_sps_name          <- system.file("extdata",
                                     "example_setup.sps",
                                     package = "asciiSetupReader")
SHR_sas_name          <- system.file("extdata",
                                     "example_setup.sas",
                                     package = "asciiSetupReader")
UCR_dataset_name      <- system.file("testdata",
                                     "ucr1960.zip",
                                     package = "asciiSetupReader")
UCR_sps_name          <- system.file("testdata",
                                     "ucr1960_sps.zip",
                                     package = "asciiSetupReader")
UCR_sas_name          <- system.file("testdata",
                                     "ucr1960_sas.zip",
                                     package = "asciiSetupReader")
NIBRS_dataset_name    <- system.file("testdata",
                                     "nibrs_2000_batch_header1.zip",
                                     package = "asciiSetupReader")
NIBRS_sps_name        <- system.file("testdata",
                                     "nibrs_2000_batch_header1_sps.zip",
                                     package = "asciiSetupReader")
NIBRS_sas_name        <- system.file("testdata",
                                     "nibrs_2000_batch_header1_sas.zip",
                                     package = "asciiSetupReader")
weimar_dataset_name   <- system.file("testdata",
                                     "weimar.txt",
                                     package = "asciiSetupReader")
weimar_sps_name       <- system.file("testdata",
                                     "weimar_sps.zip",
                                     package = "asciiSetupReader")
weimar_sas_name       <- system.file("testdata",
                                     "weimar_sas.zip",
                                     package = "asciiSetupReader")
# crosswalk_dataset_name     <- system.file("testdata",
#                                           "crosswalk.zip",
#                                           package = "asciiSetupReader")
crosswalk_sps_name         <- system.file("testdata",
                                          "crosswalk.sps",
                                          package = "asciiSetupReader")
ucr1985_sps_name           <- system.file("testdata",
                                          "1985_UCR_offenses_known_sps.zip",
                                          package = "asciiSetupReader")
ucr1986_sps_name           <- system.file("testdata",
                                          "1986_UCR_offenses_known_sps.zip",
                                          package = "asciiSetupReader")
ucr2000_sps_name           <- system.file("testdata",
                                          "2000_UCR_offenses_known_sps.zip",
                                          package = "asciiSetupReader")
ucr2006_sps_name           <- system.file("testdata",
                                          "2006_UCR_offenses_known_sps.zip",
                                          package = "asciiSetupReader")
sac_sps_name               <- system.file("testdata",
                                          "sacramento_sps.zip",
                                          package = "asciiSetupReader")
sex_offender_sps_name      <- system.file("testdata",
                                          "sex_offender_notification.sps",
                                          package = "asciiSetupReader")
ucr1960_sps_name           <- system.file("testdata",
                                          "ucr1960_sps.zip",
                                          package = "asciiSetupReader")
acs_sps_name               <- system.file("testdata",
                                          "acs_sps.zip",
                                          package = "asciiSetupReader")
nibrs_sps_name             <- system.file("testdata",
                                          "nibrs_2000_batch_header1_sps.zip",
                                          package = "asciiSetupReader")
prisoners_sps_name         <- system.file("testdata",
                                          "prisoners_sps.zip",
                                          package = "asciiSetupReader")
SHR1987_sps_name           <- system.file("testdata",
                                          "1987_SHR_sps.zip",
                                          package = "asciiSetupReader")
SHR1988_sps_name           <- system.file("testdata",
                                          "1988_SHR_sps.zip",
                                          package = "asciiSetupReader")
SHR1981_sps_name           <- system.file("testdata",
                                          "1981_SHR_sps.zip",
                                          package = "asciiSetupReader")
ca_vital_sps_name          <- system.file("testdata",
                                          "ca_vital.sps",
                                          package = "asciiSetupReader")
parole_sps_name            <- system.file("testdata",
                                          "parole_survey.sps",
                                          package = "asciiSetupReader")
parole_survey_dataset_name <- system.file("testdata",
                                          "parole_survey.txt",
                                          package = "asciiSetupReader")
SHR1987_sps_name           <- system.file("testdata",
                                          "1987_SHR_sps.zip",
                                          package = "asciiSetupReader")
SHR1988_sps_name           <- system.file("testdata",
                                          "1988_SHR_sps.zip",
                                          package = "asciiSetupReader")
SHR1981_sps_name           <- system.file("testdata",
                                          "1981_SHR_sps.zip",
                                          package = "asciiSetupReader")
leoka1980_sps_name         <- system.file("testdata",
                                          "1980_leoka_sps.zip",
                                          package = "asciiSetupReader")
property_stolen_sps_name   <- system.file("testdata",
                                          "ucr_property_stolen_1998_sps.zip",
                                          package = "asciiSetupReader")
ncvs_sps_name              <- system.file("testdata",
                                          "ncvs_1979_sps.zip",
                                          package = "asciiSetupReader")
jail_1987_sps_name         <- system.file("testdata",
                                          "jail_survey_1987.sps",
                                          package = "asciiSetupReader")
jail_2010_sps_name         <- system.file("testdata",
                                          "jail_survey_2010.sps",
                                          package = "asciiSetupReader")
jail_1987_dataset_name     <- system.file("testdata",
                                          "jail_survey_1987.zip",
                                          package = "asciiSetupReader")
corrections_sps_name       <- system.file("testdata",
                                          "corrections_prison_admissions_1991_2016.sps",
                                          package = "asciiSetupReader")
sadc_sps_name              <- system.file("testdata",
                                          "2017_sadc_spss_input_program.sps",
                                          package = "asciiSetupReader")
crosswalk2012_sps_name     <- system.file("testdata",
                                          "crosswalk2012.sps",
                                          package = "asciiSetupReader")
dutch_election_sps_name    <- system.file("testdata",
                                          "dutch_election_study_sps.zip",
                                          package = "asciiSetupReader")
well_being_sps_name        <- system.file("testdata",
                                          "WB2016.sps",
                                          package = "asciiSetupReader")
escolar_sps_name           <- system.file("testdata",
                                          "escolar.SPS",
                                          package = "asciiSetupReader")

ad_health_sps_name        <- system.file("testdata",
                                         "study_of_adolescent_health.sps",
                                         package = "asciiSetupReader")
health_nutrition_sps_name <- system.file("testdata",
                                         "health_and_nutrition.sps",
                                         package = "asciiSetupReader")
india_human_sps_name  <- system.file("testdata",
                                     "india_human_development_sps.zip",
                                     package = "asciiSetupReader")
british_crime_teen_sps_name  <- system.file("testdata",
                                            "british_crime_teen_sps.zip",
                                            package = "asciiSetupReader")
drug_abuse_sps_name          <- system.file("testdata",
                                            "drug_abuse_sps.zip",
                                            package = "asciiSetupReader")
worry_sps_name               <- system.file("testdata",
                                            "worry_sps.zip",
                                            package = "asciiSetupReader")
cps_1973_sps_name            <- system.file("testdata",
                                            "cps_1973_sps.zip",
                                            package = "asciiSetupReader")
cps_2004_sps_name           <- system.file("testdata",
                                           "cps_2004_sps.zip",
                                           package = "asciiSetupReader")
census_police_sps_name      <- system.file("testdata",
                                           "census_of_police.sps",
                                           package = "asciiSetupReader")
detroit_sps_name            <- system.file("testdata",
                                           "detroit_sps.zip",
                                           package = "asciiSetupReader")
step_in_sps_name            <- system.file("testdata",
                                           "step_in.sps",
                                           package = "asciiSetupReader")
cambridge_sps_name     <- system.file("testdata",
                                      "cambridge_sps.zip",
                                      package = "asciiSetupReader")
guam_sps_name          <- system.file("testdata",
                                      "guam_sps.zip",
                                      package = "asciiSetupReader")
china_2002_sps_name    <- system.file("testdata",
                                      "china_2002.sps",
                                      package = "asciiSetupReader")
china_1995_sps_name    <- system.file("testdata",
                                      "china_1995.sps",
                                      package = "asciiSetupReader")
china_1998_sps_name    <- system.file("testdata",
                                      "china_1998.sps",
                                      package = "asciiSetupReader")
indonesia_sps_name     <- system.file("testdata",
                                      "indonesia.sps",
                                      package = "asciiSetupReader")
UN_crime_sps_name      <- system.file("testdata",
                                      "UN_crime.sps",
                                      package = "asciiSetupReader")
county_arrest_sps_name <- system.file("testdata",
                                      "county_arrest.sps",
                                      package = "asciiSetupReader")
escolar_2006_sps_name <- system.file("testdata",
                                  "escolar_2006_sps.zip",
                                  package = "asciiSetupReader")
mtf_1999_sps_name     <- system.file("testdata",
                                     "monitoring_the_future_1999_sps.zip",
                                     package = "asciiSetupReader")
mtf_2003_sps_name     <- system.file("testdata",
                                 "monitoring_the_future_2003_sps.zip",
                                 package = "asciiSetupReader")
mtf_1990_sps_name     <- system.file("testdata",
                                 "monitoring_the_future_1990_sps.zip",
                                 package = "asciiSetupReader")
mtf_1989_sps_name     <- system.file("testdata",
                                 "monitoring_the_future_1989_sps.zip",
                                 package = "asciiSetupReader")
mtf_2004_sps_name     <- system.file("testdata",
                                 "monitoring_the_future_2004_sps.zip",
                                 package = "asciiSetupReader")
mtf_2002_sps_name     <- system.file("testdata",
                                 "monitoring_the_future_2002_sps.zip",
                                 package = "asciiSetupReader")
mtf_1993_sps_name     <- system.file("testdata",
                                 "monitoring_the_future_1993_sps.zip",
                                 package = "asciiSetupReader")
mtf_1991_sps_name     <- system.file("testdata",
                                     "monitoring_the_future_1991_sps.zip",
                                     package = "asciiSetupReader")
mtf_1992_sps_name     <- system.file("testdata",
                                     "monitoring_the_future_1992_sps.zip",
                                     package = "asciiSetupReader")
mtf_1979_sps_name     <- system.file("testdata",
                                     "monitoring_the_future_1979_sps.zip",
                                     package = "asciiSetupReader")


cambridge_sas_name     <- system.file("testdata",
                                      "cambridge_sas.zip",
                                      package = "asciiSetupReader")
guam_sas_name          <- system.file("testdata",
                                      "guam_sas.zip",
                                      package = "asciiSetupReader")
china_2002_sas_name    <- system.file("testdata",
                                      "china_2002.sas",
                                      package = "asciiSetupReader")
china_1995_sas_name    <- system.file("testdata",
                                      "china_1995.sas",
                                      package = "asciiSetupReader")
china_1998_sas_name    <- system.file("testdata",
                                      "china_1998.sas",
                                      package = "asciiSetupReader")
indonesia_sas_name     <- system.file("testdata",
                                      "indonesia.sas",
                                      package = "asciiSetupReader")
UN_crime_sas_name      <- system.file("testdata",
                                      "UN_crime.sas",
                                      package = "asciiSetupReader")
county_arrest_sas_name <- system.file("testdata",
                                      "county_arrest.sas",
                                      package = "asciiSetupReader")





british_crime_teen_sas_name  <- system.file("testdata",
                                            "british_crime_teen_sas.zip",
                                            package = "asciiSetupReader")
drug_abuse_sas_name          <- system.file("testdata",
                                            "drug_abuse_sas.zip",
                                            package = "asciiSetupReader")
worry_sas_name               <- system.file("testdata",
                                            "worry_sas.zip",
                                            package = "asciiSetupReader")
cps_1973_sas_name            <- system.file("testdata",
                                            "cps_1973_sas.zip",
                                            package = "asciiSetupReader")
education_1985_sas_name     <- system.file("testdata",
                                           "education_1985.sas",
                                           package = "asciiSetupReader")
education_1995_sas_name     <- system.file("testdata",
                                           "education_1995.sas",
                                           package = "asciiSetupReader")
cps_2004_sas_name           <- system.file("testdata",
                                           "cps_2004_sas.zip",
                                           package = "asciiSetupReader")
census_police_sas_name      <- system.file("testdata",
                                           "census_of_police.sas",
                                           package = "asciiSetupReader")
detroit_sas_name            <- system.file("testdata",
                                           "detroit_sas.zip",
                                           package = "asciiSetupReader")
step_in_sas_name            <- system.file("testdata",
                                           "step_in.sas",
                                           package = "asciiSetupReader")
psid_toy_sas_name          <- system.file("testdata",
                                          "psid_toy.sas",
                                          package = "asciiSetupReader")

health_nutrition_sas_name  <- system.file("testdata",
                                          "health_and_nutrition.sas",
                                          package = "asciiSetupReader")
india_human_sas_name       <- system.file("testdata",
                                          "india_human_development_sas.zip",
                                          package = "asciiSetupReader")
well_being_sas_name        <- system.file("testdata",
                                          "WB2016.sas",
                                          package = "asciiSetupReader")
crosswalk_sas_name         <- system.file("testdata",
                                          "crosswalk.sas",
                                          package = "asciiSetupReader")
ucr1985_sas_name           <- system.file("testdata",
                                          "1985_UCR_offenses_known_sas.zip",
                                          package = "asciiSetupReader")
ucr1986_sas_name           <- system.file("testdata",
                                          "1986_UCR_offenses_known_sas.zip",
                                          package = "asciiSetupReader")
ucr2000_sas_name           <- system.file("testdata",
                                          "2000_UCR_offenses_known_sas.zip",
                                          package = "asciiSetupReader")
ucr2006_sas_name           <- system.file("testdata",
                                          "2006_UCR_offenses_known_sas.zip",
                                          package = "asciiSetupReader")
sac_sas_name               <- system.file("testdata",
                                          "sacramento_sas.zip",
                                          package = "asciiSetupReader")
sex_offender_sas_name      <- system.file("testdata",
                                          "sex_offender_notification.sas",
                                          package = "asciiSetupReader")
ucr1960_sas_name           <- system.file("testdata",
                                          "ucr1960_sas.zip",
                                          package = "asciiSetupReader")
acs_sas_name               <- system.file("testdata",
                                          "acs_sas.zip",
                                          package = "asciiSetupReader")
nibrs_sas_name             <- system.file("testdata",
                                          "nibrs_2000_batch_header1_sas.zip",
                                          package = "asciiSetupReader")
prisoners_sas_name         <- system.file("testdata",
                                          "prisoners_sas.zip",
                                          package = "asciiSetupReader")
SHR1987_sas_name           <- system.file("testdata",
                                          "1987_SHR_sas.zip",
                                          package = "asciiSetupReader")
SHR1988_sas_name           <- system.file("testdata",
                                          "1988_SHR_sas.zip",
                                          package = "asciiSetupReader")
SHR1981_sas_name           <- system.file("testdata",
                                          "1981_SHR_sas.zip",
                                          package = "asciiSetupReader")
ca_vital_sas_name          <- system.file("testdata",
                                          "ca_vital.sas",
                                          package = "asciiSetupReader")
parole_sas_name            <- system.file("testdata",
                                          "parole_survey.sas",
                                          package = "asciiSetupReader")
SHR1987_sas_name           <- system.file("testdata",
                                          "1987_SHR_sas.zip",
                                          package = "asciiSetupReader")
SHR1988_sas_name           <- system.file("testdata",
                                          "1988_SHR_sas.zip",
                                          package = "asciiSetupReader")
SHR1981_sas_name           <- system.file("testdata",
                                          "1981_SHR_sas.zip",
                                          package = "asciiSetupReader")
leoka1980_sas_name         <- system.file("testdata",
                                          "1980_leoka_sas.zip",
                                          package = "asciiSetupReader")
property_stolen_sas_name   <- system.file("testdata",
                                          "ucr_property_stolen_1998_sas.zip",
                                          package = "asciiSetupReader")
ncvs_sas_name              <- system.file("testdata",
                                          "ncvs_1979_sas.zip",
                                          package = "asciiSetupReader")
jail_1987_sas_name         <- system.file("testdata",
                                          "jail_survey_1987.sas",
                                          package = "asciiSetupReader")
jail_2010_sas_name         <- system.file("testdata",
                                          "jail_survey_2010.sas",
                                          package = "asciiSetupReader")
jail_1987_dataset_name     <- system.file("testdata",
                                          "jail_survey_1987.zip",
                                          package = "asciiSetupReader")
corrections_sas_name       <- system.file("testdata",
                                          "corrections_prison_admissions_1991_2016.sas",
                                          package = "asciiSetupReader")
sadc_sas_name              <- system.file("testdata",
                                          "2017_sadc_sas_input_program.sas",
                                          package = "asciiSetupReader")


parole <- read_ascii_setup(data = parole_survey_dataset_name,
                           setup_file = parole_sps_name,
                           use_clean_names = FALSE)

SHR2 <- read_ascii_setup(data = SHR_dataset_name,
                         setup_file = SHR_sps_name, select_columns = 1:5)
SHR3 <- read_ascii_setup(data = SHR_dataset_name,
                         setup_file = SHR_sps_name,
                         select_columns = c(1, 5, 50:55, 100:121, 152))
UCR2 <- read_ascii_setup(data = UCR_dataset_name,
                         setup_file = UCR_sps_name,
                         select_columns = c("V1", "V50", "V100", "V111",
                                            "V1000"))
NIBRS2 <- read_ascii_setup(data = NIBRS_dataset_name,
                           setup_file = NIBRS_sps_name,
                           select_columns = c("B1001", "B1005", "B1010",
                                              "B1016", "B1019"))

# Read SAS ====================================================================
SHR2_sas   <- read_ascii_setup(data = SHR_dataset_name,
                               setup_file = SHR_sas_name, select_columns = 1:5)
SHR3_sas   <- read_ascii_setup(data = SHR_dataset_name,
                               setup_file = SHR_sas_name,
                               select_columns = c(1, 5, 50:55, 100:121, 152))
UCR2_sas   <- read_ascii_setup(data = UCR_dataset_name,
                               setup_file = UCR_sas_name,
                               select_columns = c("V1", "V50", "V100",
                                                  "V111", "V1000"))
NIBRS2_sas <- read_ascii_setup(data = NIBRS_dataset_name,
                               setup_file = NIBRS_sas_name,
                               select_columns = c("B1001", "B1005",
                                                  "B1010", "B1016", "B1019"))

SHR        <- read_ascii_setup(data = SHR_dataset_name,
                               setup_file = SHR_sps_name)
UCR        <- read_ascii_setup(data = UCR_dataset_name,
                               setup_file = UCR_sps_name,
                               select_columns = 1:150)
NIBRS      <- read_ascii_setup(data = NIBRS_dataset_name,
                               setup_file = NIBRS_sps_name)
SHR_sas    <- read_ascii_setup(data = SHR_dataset_name,
                               setup_file = SHR_sas_name)
UCR_sas    <- read_ascii_setup(data = UCR_dataset_name,
                               setup_file = UCR_sas_name,
                               select_columns = 1:150)
NIBRS_sas  <- read_ascii_setup(data = NIBRS_dataset_name,
                               setup_file = NIBRS_sas_name)
weimar     <- read_ascii_setup(data = weimar_dataset_name,
                               setup_file = weimar_sps_name)
weimar_sas <- read_ascii_setup(data = weimar_dataset_name,
                               setup_file = weimar_sas_name)



SHR_names    <- read_ascii_setup(data = SHR_dataset_name,
                                 setup_file = SHR_sps_name,
                                 select_columns = c(1, 33, 45, 72, 100, 152))
SHR2_names   <- read_ascii_setup(data = SHR_dataset_name,
                                 setup_file = SHR_sps_name,
                                 use_clean_names = FALSE,
                                 select_columns = c(1, 33, 45, 72, 100, 152))
UCR_names    <- read_ascii_setup(data = UCR_dataset_name,
                                 setup_file = UCR_sps_name,
                                 select_columns = c(1, 33, 345, 572, 1000, 1400))
UCR2_names   <- read_ascii_setup(data = UCR_dataset_name,
                                 setup_file = UCR_sps_name,
                                 select_columns = c(1, 33, 345, 572, 1000, 1400),
                                 use_clean_names = FALSE)
NIBRS_names   <- read_ascii_setup(data = NIBRS_dataset_name,
                                  setup_file = NIBRS_sps_name,
                                  select_columns = c(1, 3, 5, 7, 10, 15))
NIBRS2_names  <- read_ascii_setup(data = NIBRS_dataset_name,
                                  setup_file = NIBRS_sps_name,
                                  use_clean_names = FALSE,
                                  select_columns = c(1, 3, 5, 7, 10, 15))

weimar_names  <- read_ascii_setup(data = weimar_dataset_name,
                                  setup_file = weimar_sps_name,
                                  select_columns = c(1:7, 23))
weimar2_names <- read_ascii_setup(data = weimar_dataset_name,
                                  setup_file = weimar_sps_name,
                                  use_clean_names = FALSE)


# Read SAS ===============================================================
SHR_sas_names     <- read_ascii_setup(data = SHR_dataset_name,
                                      setup_file = SHR_sas_name,
                                      select_columns = c(1, 33, 45, 72, 100, 152))
SHR2_sas_names    <- read_ascii_setup(data = SHR_dataset_name,
                                      setup_file = SHR_sas_name,
                                      use_clean_names = FALSE,
                                      select_columns = c(1, 33, 45,
                                                         72, 100, 152))
UCR_sas_names     <- read_ascii_setup(data = UCR_dataset_name,
                                      setup_file = UCR_sas_name,
                                      select_columns = c(1, 33, 345,
                                                         572, 1000, 1400))
UCR2_sas_names    <- read_ascii_setup(data = UCR_dataset_name,
                                      setup_file = UCR_sas_name,
                                      select_columns = c(1, 33, 345,
                                                         572, 1000, 1400),
                                      use_clean_names = FALSE)
NIBRS_sas_names   <- read_ascii_setup(data = NIBRS_dataset_name,
                                      setup_file = NIBRS_sas_name,
                                      select_columns = c(1, 3, 5, 7, 10, 15))
NIBRS2_sas_names  <- read_ascii_setup(data = NIBRS_dataset_name,
                                      setup_file = NIBRS_sas_name,
                                      use_clean_names = FALSE,
                                      select_columns = c(1, 3, 5, 7, 10, 15))

weimar_sas_names  <- read_ascii_setup(data = weimar_dataset_name,
                                      setup_file = weimar_sas_name,
                                      select_columns = c(1:7, 23))
weimar2_sas_names <- read_ascii_setup(data = weimar_dataset_name,
                                      setup_file = weimar_sas_name,
                                      use_clean_names = FALSE)
# crosswalk         <- read_ascii_setup(data = crosswalk_dataset_name,
#                                       setup_file = crosswalk_sps_name,
#                                       use_clean_names = FALSE)

parole_parsed_sps          <- parse_setup(parole_sps_name)
sac_parsed_sps             <- parse_setup(sac_sps_name)
sex_offender_parsed_sps    <- parse_setup(sex_offender_sps_name)
ucr1960_parsed_sps         <- parse_setup(ucr1960_sps_name)
weimar_parsed_sps          <- parse_setup(weimar_sps_name)
acs_parsed_sps             <- parse_setup(acs_sps_name)
nibrs_parsed_sps           <- parse_setup(nibrs_sps_name)
prisoners_parsed_sps       <- parse_setup(prisoners_sps_name)
ca_vital_parsed_sps        <- parse_setup(ca_vital_sps_name)
crosswalk_parsed_sps       <- parse_setup(crosswalk_sps_name)
ucr1985_parsed_sps         <- parse_setup(ucr1985_sps_name)
ucr1986_parsed_sps         <- parse_setup(ucr1986_sps_name)
ucr2000_parsed_sps         <- parse_setup(ucr2000_sps_name)
#ucr2006_parsed_sps         <- parse_setup(ucr2006_sps_name)
SHR1987_parsed_sps         <- parse_setup(SHR1987_sps_name)
SHR1988_parsed_sps         <- parse_setup(SHR1988_sps_name)
SHR1981_parsed_sps         <- parse_setup(SHR1981_sps_name)
leoka1980_parsed_sps       <- parse_setup(leoka1980_sps_name)
property_stolen_parsed_sps <- parse_setup(property_stolen_sps_name)
ncvs_parsed_sps            <- parse_setup(ncvs_sps_name)
jail_1987_parsed_sps       <- parse_setup(jail_1987_sps_name)
jail_2010_parsed_sps       <- parse_setup(jail_2010_sps_name)
corrections_parsed_sps     <- parse_setup(corrections_sps_name)
sadc_parsed_sps            <- parse_setup(sadc_sps_name)
crosswalk2012_parsed_sps   <- parse_setup(crosswalk2012_sps_name)
dutch_election_parsed_sps  <- parse_setup(dutch_election_sps_name)
well_being_parsed_sps      <- parse_setup(well_being_sps_name)
escolar_parsed_sps          <- parse_setup(escolar_sps_name)
ad_health_parsed_sps        <- parse_setup(ad_health_sps_name)
health_nutrition_parsed_sps <- parse_setup(health_nutrition_sps_name)
india_human_parsed_sps      <- parse_setup(india_human_sps_name)
step_in_parsed_sps          <- parse_setup(step_in_sps_name)
cps_1973_parsed_sps         <- parse_setup(cps_1973_sps_name)
census_police_parsed_sps    <- parse_setup(census_police_sps_name)
british_crime_teen_parsed_sps <- parse_setup(british_crime_teen_sps_name)
drug_abuse_parsed_sps         <- parse_setup(drug_abuse_sps_name)
detroit_parsed_sps            <- parse_setup(detroit_sps_name)
worry_parsed_sps              <- parse_setup(worry_sps_name)
cps_2004_parsed_sps           <- parse_setup(cps_2004_sps_name)
cambridge_parsed_sps     <- parse_setup(cambridge_sps_name)
guam_parsed_sps          <- parse_setup(guam_sps_name)
china_2002_parsed_sps    <- parse_setup(china_2002_sps_name)
china_1995_parsed_sps    <- parse_setup(china_1995_sps_name)
china_1998_parsed_sps    <- parse_setup(china_1998_sps_name)
indonesia_parsed_sps     <- parse_setup(indonesia_sps_name)
UN_crime_parsed_sps      <- parse_setup(UN_crime_sps_name)
county_arrest_parsed_sps <- parse_setup(county_arrest_sps_name)
cambridge_parsed_sas     <- parse_setup(cambridge_sas_name)
guam_parsed_sas          <- parse_setup(guam_sas_name)
china_2002_parsed_sas    <- parse_setup(china_2002_sas_name)
china_1995_parsed_sas    <- parse_setup(china_1995_sas_name)
china_1998_parsed_sas    <- parse_setup(china_1998_sas_name)
indonesia_parsed_sas     <- parse_setup(indonesia_sas_name)
UN_crime_parsed_sas      <- parse_setup(UN_crime_sas_name)
county_arrest_parsed_sas <- parse_setup(county_arrest_sas_name)
escolar_2006_parsed_sps  <- parse_setup(escolar_2006_sps_name)
mtf_1999_parsed_sps      <- parse_setup(mtf_1999_sps_name)
mtf_2003_parsed_sps      <- parse_setup(mtf_2003_sps_name)
mtf_1990_parsed_sps      <- parse_setup(mtf_1990_sps_name)
mtf_1989_parsed_sps      <- parse_setup(mtf_1989_sps_name)
mtf_2004_parsed_sps      <- parse_setup(mtf_2004_sps_name)
mtf_2002_parsed_sps      <- parse_setup(mtf_2002_sps_name)
mtf_1993_parsed_sps      <- parse_setup(mtf_1993_sps_name)
mtf_1991_parsed_sps      <- parse_setup(mtf_1991_sps_name)
mtf_1992_parsed_sps      <- parse_setup(mtf_1992_sps_name)
mtf_1979_parsed_sps      <- parse_setup(mtf_1979_sps_name)


british_crime_teen_parsed_sas <- parse_setup(british_crime_teen_sas_name)
drug_abuse_parsed_sas         <- parse_setup(drug_abuse_sas_name)
detroit_parsed_sas            <- parse_setup(detroit_sas_name)
worry_parsed_sas              <- parse_setup(worry_sas_name)
cps_2004_parsed_sas           <- parse_setup(cps_2004_sas_name)
step_in_parsed_sas          <- parse_setup(step_in_sas_name)
education_1985_parsed_sas   <- parse_setup(education_1985_sas_name)
education_1995_parsed_sas   <- parse_setup(education_1995_sas_name)
cps_1973_parsed_sas         <- parse_setup(cps_1973_sas_name)
census_police_parsed_sas    <- parse_setup(census_police_sas_name)
psid_toy_parsed_sas         <- parse_setup(psid_toy_sas_name)
health_nutrition_parsed_sas <- parse_setup(health_nutrition_sas_name)
india_human_parsed_sas      <- parse_setup(india_human_sas_name)
well_being_parsed_sas       <- parse_setup(well_being_sas_name)
parole_parsed_sas           <- parse_setup(parole_sas_name)
sac_parsed_sas              <- parse_setup(sac_sas_name)
sex_offender_parsed_sas     <- parse_setup(sex_offender_sas_name)
ucr1960_parsed_sas          <- parse_setup(ucr1960_sas_name)
weimar_parsed_sas           <- parse_setup(weimar_sas_name)
acs_parsed_sas              <- parse_setup(acs_sas_name)
nibrs_parsed_sas            <- parse_setup(nibrs_sas_name)
prisoners_parsed_sas        <- parse_setup(prisoners_sas_name)
ca_vital_parsed_sas         <- parse_setup(ca_vital_sas_name)
crosswalk_parsed_sas        <- parse_setup(crosswalk_sas_name)
ucr1985_parsed_sas          <- parse_setup(ucr1985_sas_name)
ucr1986_parsed_sas          <- parse_setup(ucr1986_sas_name)
ucr2000_parsed_sas          <- parse_setup(ucr2000_sas_name)
#ucr2006_parsed_sas         <- parse_setup(ucr2006_sas_name)
SHR1987_parsed_sas          <- parse_setup(SHR1987_sas_name)
SHR1988_parsed_sas          <- parse_setup(SHR1988_sas_name)
SHR1981_parsed_sas          <- parse_setup(SHR1981_sas_name)
leoka1980_parsed_sas        <- parse_setup(leoka1980_sas_name)
property_stolen_parsed_sas  <- parse_setup(property_stolen_sas_name)
ncvs_parsed_sas             <- parse_setup(ncvs_sas_name)
jail_1987_parsed_sas        <- parse_setup(jail_1987_sas_name)
jail_2010_parsed_sas        <- parse_setup(jail_2010_sas_name)
corrections_parsed_sas      <- parse_setup(corrections_sas_name)
SHR_parsed_sas              <- parse_setup(SHR_sas_name)
#sadc_parsed_sas            <- parse_setup(sadc_sas_name)
